pub struct ASCIIGenerator { /* private fields */ }Expand description
A struct used to control the specifics of how an image is converted into ASCII.
Note: Color functions are only available with the “color” feature.
Implementations
Sourceimpl ASCIIGenerator
impl ASCIIGenerator
Sourcepub fn set_resize_mod(&mut self, resize_mode: ResizeMode) -> &mut Self
pub fn set_resize_mod(&mut self, resize_mode: ResizeMode) -> &mut Self
Sets the resize mode used when the ASCII is generated.
See ResizeMode
Sourcepub fn set_color(&mut self, color: bool) -> &mut Self
Available on crate feature color only.
pub fn set_color(&mut self, color: bool) -> &mut Self
color only.Sets whether or not to generate the art with color.
Sourcepub fn generate<P: AsRef<Path>>(
&self,
image_path: P,
) -> Result<Vec<Line>, ASCIIError>
pub fn generate<P: AsRef<Path>>( &self, image_path: P, ) -> Result<Vec<Line>, ASCIIError>
Using the current settings, generates image into ASCII.
Throws an ASCIIError if the image at the provided path cannot be found or read.